@@ -250,7 +250,9 @@ prompt, otherwise a value of false is returned.
                     $self->debug("enable enable_in prompt starting");
                     {
                         local $SIG{INT} = sub {
-                            system("stty echo 2>/dev/null")
+                            system("stty echo 2>/dev/null");
+                            syswrite STDERR, "\n\n";
+                            $self->fatal("interrupt signal received");
                         };
                         syswrite STDERR,
                             "\nEnter enable $self->expect->match: ";
@@ -291,8 +293,8 @@ sub close {
     $expect->close
 
 This method sends the end and exit ios commands before closing the current
-expect session. Timeouts are gracefully handled. Refer to the close method
-in the L<Mnet::Expect::Cli> module for more information.
+expect session. Timeouts and disconnects are gracefully handled. Refer to the
+close method in the L<Mnet::Expect::Cli> module for more information.
 
 =cut
 
