@@ -43,6 +43,7 @@ use warnings;
 use strict;
 use Carp;
 use Exporter qw( import );
+use Mnet;
 use Mnet::Opts::Cli::Cache;
 
 # export function names
@@ -129,7 +130,7 @@ sub notice {
 
     # call Mnet::Log::output if loaded or return;
     my ($self, $text) = (shift, shift);
-    return Mnet::Log::output($self, " - ", 5, scalar(caller), $text)
+    return Mnet::Log::output($self, "---", 5, scalar(caller), $text)
         if $INC{"Mnet/Log.pm"};
     return 1;
 }
@@ -238,7 +239,7 @@ sub NOTICE {
 
     # call Mnet::Log::output if loaded or return;
     my $text = shift;
-    return Mnet::Log::output(undef, " - ", 5, scalar(caller), $text)
+    return Mnet::Log::output(undef, "---", 5, scalar(caller), $text)
         if $INC{"Mnet/Log.pm"};
     return 1;
 }
