@@ -10,7 +10,7 @@ Mnet::Tee - Redirect stdout and stderr to a file
     use Mnet::Tee;
     Mnet::Tee::file($file);
 
-    # ot use with Mnet command line options
+    # or use with Mnet command line options
     use Mnet::Tee;
     use Mnet::Opts::Cli;
     my $cli = Mnet::Opts::Cli->new;
@@ -35,8 +35,7 @@ Note that output captured by this module is stored in memory during script
 execution. That could be a problem for scripts that generate gigabytes of
 stdout and/or stderr output.
 
-The perl tie command is used to implement the functionality of this module
-and requires perl 5.010 or newer.
+The perl tie command used in this module requires perl 5.010 or newer.
 
 =head1 FUNCTIONS
 
@@ -45,12 +44,14 @@ Mnet::Tee implements the functions listed below.
 =cut
 
 # required modules
-#   perl 5.10 may be requried for tie to capture stdout and stderr
+#   perl 5.10 for tie to capture stdout/stderr
+#       update Mnet.pm and this perldoc if changed
 use warnings;
 use strict;
 use 5.010;
 use Carp;
 use Exporter qw( import );
+use Mnet;
 use Mnet::Log::Conditional qw( DEBUG INFO WARN FATAL NOTICE );
 use Mnet::Opts::Cli::Cache;
 
@@ -62,9 +63,13 @@ our @EXPORT_OK = qw( $stderr $stdout );
 # begin block to initialize capture of stdout and stderr
 BEGIN {
 
+    # autoflush standard output
+    #   so that multi-process syswrite lines are not split
+    $| = 1;
+
     # original stderr and stdout for bypassing output captured by Mnet::Tee
-    open(our $stderr, ">&STDERR");
-    open(our $stdout, ">&STDOUT");
+    open(our $stderr, ">&STDERR") or die "error duping stderr, $!";
+    open(our $stdout, ">&STDOUT") or die "error duping stdout, $!";
 
     # init global scalar variable to accumulate stdout+stderr test outputs
     my ($test_outputs, $test_paused) = ("", undef);
